@@ -15,14 +15,11 @@ import blosc2
 
 a = np.arange(1_000_000)
 
-cparams = {
-    "codec": blosc2.Codec.ZSTD,
-    "clevel": 9,
-    "filters": [blosc2.Filter.BITSHUFFLE],
-    "filters_meta": [0],
-}
+cparams = blosc2.CParams(
+    codec=blosc2.Codec.ZSTD, clevel=9, filters=[blosc2.Filter.BITSHUFFLE], filters_meta=[0]
+)
 cframe = blosc2.pack_tensor(a, cparams=cparams)
 print("Length of packed array in bytes:", len(cframe))
 
 a2 = blosc2.unpack_tensor(cframe)
-assert np.alltrue(a == a2)
+assert np.all(a == a2)
