@@ -5,12 +5,12 @@
 # This source code is licensed under a BSD-style license (found in the
 # LICENSE file in the root directory of this source tree)
 #######################################################################
-import math
 
 import numpy as np
 import pytest
 
 import blosc2
+from blosc2.ndarray import get_chunks_idx
 
 
 def udf1p(inputs_tuple, output, offset):
@@ -18,6 +18,15 @@ def udf1p(inputs_tuple, output, offset):
     output[:] = x + 1
 
 
+if blosc2._HAS_NUMBA:
+    import numba
+
+    @numba.jit(parallel=True)
+    def udf1p_numba(inputs_tuple, output, offset):
+        x = inputs_tuple[0]
+        output[:] = x + 1
+
+
 @pytest.mark.parametrize("chunked_eval", [True, False])
 @pytest.mark.parametrize(
     ("shape", "chunks", "blocks"),
@@ -152,7 +161,8 @@ def test_0p(shape, chunks, blocks, chunked_eval):
     expr = blosc2.lazyudf(
         udf0p, (), npa.dtype, shape=shape, chunked_eval=chunked_eval, chunks=chunks, blocks=blocks
     )
-    res = expr.compute()
+    out = blosc2.empty(dtype=expr.dtype, shape=expr.shape)
+    res = expr.compute(out=out)
 
     np.testing.assert_allclose(res[...], npa)
 
@@ -339,8 +349,13 @@ def test_eval_slice(shape, chunks, blocks, slices, urlpath, contiguous, chunked_
 
 
 def udf_offset(inputs_tuple, output, offset):
-    _ = inputs_tuple[0]
-    output[:] = sum(offset)
+    x = inputs_tuple[0]
+    coords = np.zeros_like(x)
+    for n in range(x.ndim):
+        for i in range(x.shape[n]):
+            _slice = tuple(slice(None, None) if n != n_ else i for n_ in range(x.ndim))
+            coords[_slice] += offset[n] + i
+    output[:] = np.sin(coords)
 
 
 @pytest.mark.parametrize("eval_mode", ["eval", "getitem"])
@@ -355,15 +370,11 @@ def udf_offset(inputs_tuple, output, offset):
         ((8, 8), (4, 4), (2, 2), (slice(None), slice(None))),
         ((9, 8), (4, 4), (2, 3), (slice(None), slice(None))),
         ((13, 13), (10, 10), (4, 3), (slice(None), slice(None))),
-        # TODO: make this work
-        # I think the issue is in how the offsets are calculated here, in the test.
-        # Other tests involving offset with slices are working fine
-        # (e.g. test_ndarray::test_arange)
-        # ((8, 8), (4, 4), (2, 2), (slice(0, 5), slice(5, 8))),
-        # ((9, 8), (4, 4), (2, 3), (slice(0, 5), slice(5, 8))),
-        # ((40, 20), (30, 10), (5, 5), (slice(0, 5), slice(5, 20))),
-        # ((13, 13), (10, 10), (4, 3), (slice(3, 8), slice(9, 12))),
-        # ((13, 13, 10), (10, 10, 5), (5, 5, 3), (slice(0, 12), slice(3, 13), ...)),
+        ((8, 8), (4, 4), (2, 2), (slice(0, 5), slice(5, 8))),
+        ((9, 8), (4, 4), (2, 3), (slice(0, 5), slice(5, 8))),
+        ((40, 20), (30, 10), (5, 5), (slice(0, 5), slice(5, 20))),
+        ((13, 13), (10, 10), (4, 3), (slice(3, 8), slice(9, 12))),
+        ((13, 13, 10), (10, 10, 5), (5, 5, 3), (slice(0, 12), slice(3, 13), ...)),
     ],
 )
 def test_offset(shape, chunks, blocks, slices, chunked_eval, eval_mode):
@@ -372,19 +383,12 @@ def test_offset(shape, chunks, blocks, slices, chunked_eval, eval_mode):
 
     # Compute the desired output
     out = np.zeros_like(x)
-    # Calculate the number of chunks in each dimension
-    if not chunked_eval:
-        # When using prefilters/postfilters, the computation is split in blocks, not chunks
-        chunks = blocks
-    nchunks = tuple(math.ceil(x.shape[i] / blocks[i]) for i in range(len(x.shape)))
-
-    # Iterate over the chunks for computing the output
-    for index in np.ndindex(nchunks):
-        # Calculate the offset for the current chunk
-        offset = [index[i] * chunks[i] for i in range(len(index))]
-        # Apply the offset to the chunk and store the result in the output array
-        out_slice = tuple(slice(index[i] * chunks[i], (index[i] + 1) * chunks[i]) for i in range(len(index)))
-        out[out_slice] = sum(offset)
+    coords = np.zeros_like(x)
+    for n in range(x.ndim):
+        for i in range(x.shape[n]):
+            _slice = tuple(slice(None, None) if n != n_ else i for n_ in range(x.ndim))
+            coords[_slice] += i
+    out = np.sin(coords)
 
     expr = blosc2.lazyudf(
         udf_offset,
@@ -395,7 +399,7 @@ def test_offset(shape, chunks, blocks, slices, chunked_eval, eval_mode):
         blocks=blocks,
     )
     if eval_mode == "eval":
-        res = expr.compute(slices)
+        res = expr.compute(slices)  # tests slices_eval
         res = res[:]
     else:
         res = expr[slices]
@@ -455,3 +459,57 @@ def test_clip_logaddexp(shape, chunks, blocks, slices):
     np.testing.assert_allclose(expr, np.sin(np.logaddexp(npb, npa)))
     expr = blosc2.evaluate("clip(logaddexp(b, a), 6, 12)")
     np.testing.assert_allclose(expr, np.clip(np.logaddexp(npb, npa), 6, 12))
+
+
+def test_save_ludf():
+    shape = (23,)
+    npa = np.arange(start=0, stop=np.prod(shape)).reshape(shape)
+    blosc2.remove_urlpath("a.b2nd")
+    array = blosc2.asarray(npa, urlpath="a.b2nd")
+
+    # Assert that shape is computed correctly
+    npc = npa + 1
+    cparams = {"nthreads": 4}
+    urlpath = "lazyarray.b2nd"
+    blosc2.remove_urlpath(urlpath)
+
+    expr = blosc2.lazyudf(udf1p, (array,), np.float64, cparams=cparams)
+
+    expr.save(urlpath=urlpath)
+    del expr
+    expr = blosc2.open(urlpath)
+    assert isinstance(expr, blosc2.LazyUDF)
+    res_lazyexpr = expr.compute()
+    np.testing.assert_array_equal(res_lazyexpr[:], npc)
+    blosc2.remove_urlpath(urlpath)
+
+    if blosc2._HAS_NUMBA:
+        expr = blosc2.lazyudf(udf1p_numba, (array,), np.float64)
+        expr.save(urlpath=urlpath)
+        del expr
+        expr = blosc2.open(urlpath)
+        assert isinstance(expr, blosc2.LazyUDF)
+        res_lazyexpr = expr.compute()
+        np.testing.assert_array_equal(res_lazyexpr[:], npc)
+
+    blosc2.remove_urlpath("a.b2nd")
+
+
+# Test get_chunk method
+def test_get_chunk():
+    a = blosc2.linspace(0, 100, 100, shape=(10, 10), chunks=(3, 4), blocks=(2, 3))
+    expr = blosc2.lazyudf(udf1p, (a,), dtype=a.dtype, shape=a.shape)
+    nres = a[:] + 1
+    chunksize = np.prod(expr.chunks) * expr.dtype.itemsize
+    blocksize = np.prod(expr.blocks) * expr.dtype.itemsize
+    _, nchunks = get_chunks_idx(expr.shape, expr.chunks)
+    out = blosc2.empty(expr.shape, dtype=expr.dtype, chunks=expr.chunks, blocks=expr.blocks)
+    for nchunk in range(nchunks):
+        chunk = expr.get_chunk(nchunk)
+        out.schunk.update_chunk(nchunk, chunk)
+        chunksize_ = int.from_bytes(chunk[4:8], byteorder="little")
+        blocksize_ = int.from_bytes(chunk[8:12], byteorder="little")
+        # Sometimes the actual chunksize is smaller than the expected chunks due to padding
+        assert chunksize <= chunksize_
+        assert blocksize == blocksize_
+    np.testing.assert_allclose(out[:], nres)
