@@ -15,7 +15,7 @@ import blosc2
 
 
 @pytest.mark.parametrize(
-    "shape, chunks, blocks, dtype, cparams, urlpath, contiguous, meta",
+    ("shape", "chunks", "blocks", "dtype", "cparams", "urlpath", "contiguous", "meta"),
     [
         (
             (100, 1230),
@@ -100,7 +100,7 @@ def test_zeros(shape, chunks, blocks, dtype, cparams, urlpath, contiguous, meta)
 
 
 @pytest.mark.parametrize(
-    "shape, dtype",
+    ("shape", "dtype"),
     [
         (100, np.uint8),
         ((100, 1230), np.uint8),
@@ -119,6 +119,56 @@ def test_zeros_minimal(shape, dtype):
     assert shape in (a.shape, a.shape[0])
     assert a.chunks is not None
     assert a.blocks is not None
-    assert all(c >= b for c, b in zip(a.chunks, a.blocks))
+    assert all(c >= b for c, b in zip(a.chunks, a.blocks, strict=False))
     assert a.dtype == dtype
     assert a.schunk.typesize == dtype.itemsize
+
+
+@pytest.mark.parametrize("asarray", [True, False])
+@pytest.mark.parametrize("typesize", [255, 256, 257, 261, 256 * 256])
+@pytest.mark.parametrize("shape", [(1,), (3,), (10,), (2 * 10,), (2**8 - 1, 3)])
+def test_large_typesize(shape, typesize, asarray):
+    dtype = np.dtype([("f_001", "<i1", (typesize,)), ("f_002", "f4", (typesize,))])
+    a = np.zeros(shape, dtype=dtype)
+    if asarray:
+        b = blosc2.asarray(a)
+    else:
+        b = blosc2.zeros(shape, dtype=dtype)
+    assert np.array_equal(b[0], a[0])
+
+
+@pytest.mark.parametrize(
+    "dtype",
+    [
+        np.dtype(("<f8", (10,))),
+        np.dtype(("<i8", (10,))),
+        np.dtype(("<i4,>f4", (10,))),
+    ],
+)
+def test_nd_dtype(dtype):
+    # Test that the dtype is correctly set for a 1D array with a nested dtype
+    a = blosc2.zeros((1,), dtype=dtype)
+    assert a.dtype == dtype
+    b = np.zeros((1,), dtype=dtype)
+    if dtype.base.fields:  # ("<i8,>f4", (10,))
+        # Check values by converting to a dtype without a structure
+        a2 = a[:].view(dtype=np.int8)
+        b2 = b[:].view(dtype=np.int8)
+        np.testing.assert_equal(a2, b2)
+    else:
+        np.testing.assert_equal(a[:], b)
+
+
+def test_shape_empty():
+    # Test that the shape is correctly set to () for an empty array
+    a = blosc2.zeros((), dtype=np.int32)
+    assert a.shape == ()
+    assert a.dtype == np.int32
+    b = np.zeros((), dtype=np.int32)
+    np.testing.assert_equal(a[()], b)
+
+
+def test_shape_max_dims():
+    # Test that the shape cannot exceed the maximum number of dimensions
+    with pytest.raises(ValueError):
+        a = blosc2.zeros((1,) * (blosc2.MAX_DIM + 1), dtype=np.int32)
