@@ -12,21 +12,24 @@ import pytest
 
 import blosc2
 
+random = np.random.default_rng()
+
 
 @pytest.mark.parametrize("gil", [True, False])
 @pytest.mark.parametrize(
-    "object, codec",
+    ("object", "codec"),
     [
-        (np.random.randint(0, 10, 10), blosc2.Codec.LZ4),
+        (random.integers(0, 10, 10), blosc2.Codec.LZ4),
         (np.arange(10), blosc2.Codec.BLOSCLZ),
-        (np.random.randint(0, 1000 + 1, 1000), blosc2.Codec.LZ4HC),
+        (random.integers(0, 1000, 1000, endpoint=True), blosc2.Codec.LZ4HC),
         (np.arange(45, dtype=np.float64), blosc2.Codec.ZLIB),
         (np.arange(50, dtype=np.int64), blosc2.Codec.ZSTD),
     ],
 )
 def test_decompress_numpy(object, codec, gil):
     blosc2.set_releasegil(gil)
-    c = blosc2.compress(object, codec=codec)
+    typesize = None if hasattr(object, "itemsize") else 1
+    c = blosc2.compress(object, typesize=typesize, codec=codec)
 
     dest = bytearray(object)
     blosc2.decompress(c, dst=dest)
@@ -48,7 +51,7 @@ def test_decompress_numpy(object, codec, gil):
 
 
 @pytest.mark.parametrize(
-    "object, codec",
+    ("object", "codec"),
     [
         (bytearray([0, 12, 24, 33]), blosc2.Codec.LZ4),
         (bytearray([2, 45, 6, 12, 78, 43, 23, 234]), blosc2.Codec.BLOSCLZ),
@@ -57,7 +60,7 @@ def test_decompress_numpy(object, codec, gil):
     ],
 )
 def test_decompress(object, codec):
-    c = blosc2.compress(object, codec=codec)
+    c = blosc2.compress(object, typesize=1, codec=codec)
 
     dest = bytearray(object)
     blosc2.decompress(c, dst=dest)
@@ -74,7 +77,7 @@ def test_decompress(object, codec):
     assert dest5 == object
 
 
-@pytest.mark.parametrize("object, codec", [(np.arange(0), blosc2.Codec.LZ4), (b"", blosc2.Codec.ZLIB)])
+@pytest.mark.parametrize(("object", "codec"), [(np.arange(0), blosc2.Codec.LZ4), (b"", blosc2.Codec.ZLIB)])
 def test_raise_error(object, codec):
     c = blosc2.compress(object, codec=codec)
 
